:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Testing
=======

Filebrowser is shipped with a minimal django project for testing.

Run the |filebrowser| tests:

.. code-block:: console

    tox

.. warning::
    Please note that the tests will copy files to your filesystem.

Travis
------

See https://travis-ci.org/sehmaschine/django-filebrowser.
